Struct Skr
#[repr(transparent)]pub struct Skr(pub u32);Expand description
SYSCFG SRAM2 key register
Tuple Fields
0: u32Implementations
impl Skr
impl Skr
pub const fn key(&self) -> u8
pub const fn key(&self) -> u8
SRAM2 write protection key for software erase The following steps are required to unlock the write protection of the SRAM2ER bit in the SYSCFG_CFGR2 register: Write 0xCA into KEY[7:0] Write 0x53 into KEY[7:0] Writing a wrong key reactivates the write protection.
pub const fn set_key(&mut self, val: u8)
pub const fn set_key(&mut self, val: u8)
SRAM2 write protection key for software erase The following steps are required to unlock the write protection of the SRAM2ER bit in the SYSCFG_CFGR2 register: Write 0xCA into KEY[7:0] Write 0x53 into KEY[7:0] Writing a wrong key reactivates the write protection.